/*
 * Copyright (C) 2019-2021 Jolla Ltd.
 * Copyright (C) 2019-2021 Slava Monich <slava.monich@jolla.com>
 * Copyright (C) 2020 Open Mobile Platform LLC.
 *
 * You may use this file under the terms of BSD license as follows:
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *   3. Neither the names of the copyright holders nor the names of its
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef NFC_TAG_T4_PRIVATE_H
#define NFC_TAG_T4_PRIVATE_H

#include "nfc_tag_p.h"
#include "nfc_tag_t4.h"

typedef struct nfc_tag_t4_class {
    NfcTagClass parent;
} NfcTagType4Class;

NfcTagType4a*
nfc_tag_t4a_new(
    NfcTarget* target,
    const NfcParamPollA* poll_a,
    const NfcParamIsoDepPollA* iso_dep_param)
    NFCD_INTERNAL;

NfcTagType4b*
nfc_tag_t4b_new(
    NfcTarget* target,
    const NfcParamPollB* poll_b,
    const NfcParamIsoDepPollB* iso_dep_param)
    NFCD_INTERNAL;

void
nfc_tag_t4_init_base(
    NfcTagType4* tag,
    NfcTarget* target,
    guint mtu,
    const NfcParamPoll* poll,
    const NfcParamIsoDep* iso_dep)
    NFCD_INTERNAL;

/* For unit tests */
gboolean
nfc_tag_t4_build_apdu(
    GByteArray* buf,
    guint8 cla,          /* Class byte */
    guint8 ins,          /* Instruction byte */
    guint8 p1,           /* Parameter byte 1 */
    guint8 p2,           /* Parameter byte 2 */
    guint len,           /* Command data length */
    const void* data,    /* Command data */
    guint exp)           /* Expected length */
    NFCD_INTERNAL;

#endif /* NFC_TAG_T4_PRIVATE_H */

/*
 * Local Variables:
 * mode: C
 * c-basic-offset: 4
 * indent-tabs-mode: nil
 * End:
 */
